<?php

namespace Modules\Qc\Http\Controllers;

use Exception;
use Illuminate\Support\Facades\Auth;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\Qc\Entities\ProductionWeightReport;
use Modules\Qc\Entities\ProductionWeightReportHeader;

class ProductionWeightReportController extends Controller
{
    public function save(Request $request)
    {
        try {
            $rec = new ProductionWeightReportHeader();
            $rec->reference_no = $request->get('reference_no');
            $rec->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');          
            $rec->date = $request->get('date');
            $rec->factory = $request->get('factory');
            $rec->user_id = Auth::user()->id;
            if ($rec->save()) {
                $rec_arr = $request->get("pwr_data");
                for ($i = 0; $i < count($rec_arr); $i++) {
                    $pwrData = json_decode($rec_arr[$i]);

                    $rec_data = new ProductionWeightReport();
                    $rec_data->pwr_id = $rec->pwr_id;
                    $rec_data->hour = $pwrData->hour;
                    $rec_data->sample_no = $pwrData->sample_no;
                    $rec_data->ob1 = $pwrData->ob1;
                    $rec_data->ob2 = $pwrData->ob2;
                    $rec_data->ob3 = $pwrData->ob3;
                    $rec_data->ob4 = $pwrData->ob4;
                    $rec_data->ob5 = $pwrData->ob5;
                    $rec_data->save();
                }
            }
            $responseBody = $this->responseBody(true, "ProductionWeightReportController", "saved", true);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "ProductionWeightReportController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function update(Request $request, $id)
    {

        try {

            if ($this->delete($id)) {
                $rec = ProductionWeightReportHeader::find($id);
                $rec->reference_no = $request->get('reference_no');
                $rec->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');               
                $rec->date = $request->get('date');
                $rec->factory = $request->get('factory');
                $rec->update();

                $rec_arr = $request->get("pwr_data");
                if ($rec_arr) {
                    for ($i = 0; $i < count($rec_arr); $i++) {
                        $pwrData = json_decode($rec_arr[$i]);
                        $rec_data = new ProductionWeightReport();
                        $rec_data->pwr_id = $rec->pwr_id;
                        $rec_data->hour = $pwrData->hour;
                        $rec_data->sample_no = $pwrData->sample_no;
                        $rec_data->ob1 = $pwrData->ob1;
                        $rec_data->ob2 = $pwrData->ob2;
                        $rec_data->ob3 = $pwrData->ob3;
                        $rec_data->ob4 = $pwrData->ob4;
                        $rec_data->ob5 = $pwrData->ob5;
                        $rec_data->save();
                    }
                }
            }

            $responseBody = $this->responseBody(true, "ProductionWeightReportController", "update", true);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "ProductionWeightReportController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function delete($id)
    {
        try {
            $rec_data = ProductionWeightReport::where('pwr_id', '=', $id)->get();
            foreach ($rec_data as $data) {
                $data->delete();
            }
            return true;
        } catch (Exception $exception) {
            return false;
        }
    }

    public function getPwrData($id)
    {
        try {
            $recordHead = ProductionWeightReportHeader::find($id);
            $recordData = ProductionWeightReport::where('pwr_id', '=', $id)->get();

            foreach ($recordData as $data) {
                $average = ($data->ob1 + $data->ob2 + $data->ob3 + $data->ob4 + $data->ob5)/5;
                $data->average = $average;
            }

            $recordHead->request_data = $recordData;

            $responseBody = $this->responseBody(true, "ProductionWeightReportController", "getPwrData", $recordHead);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "ProductionWeightReportController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
