$(document).ready(function () {
    $("#myTable").DataTable({
        scrollX: true,
        order: [],
        columns: [
            { data: "Order No" },
            { data: "Product" },
            { data: "Factory Order Number" },
            { data: "Total Damage" },
            { data: "Date & Time" },
            { data: "edit", className: "edit", orderable: false },
            { data: "view", className: "view", orderable: false },
            { data: "print", className: "print", orderable: false },
            { data: "delete", className: "delete", orderable: false },
        ],
        columnDefs: [
            { width: 30, targets: 5 },
            { width: 30, targets: 6 },
            { width: 30, targets: 7 },
            { width: 30, targets: 8 },
        ],
    });

    allDcRecords();
});

function allDcRecords() {
    $.ajax({
        type: "GET",
        url: "/qc/DamageCheckingRecordsHeaderController/records",
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () { },
        success: function (response) {
            if (response.data.success) {
                var data = [];

                for (i = 0; i < response.data.result.length; i++) {
                    var purchase_order =
                        response.data.result[i]["purchase_order"];
                    var product_name = response.data.result[i]["product_name"];
                    var manufacturing_order_no =
                        response.data.result[i]["manufacturing_order_no"];
                    var trans_date_time =
                        response.data.result[i]["trans_date_time"];
                    var dcr_id = response.data.result[i]["dcr_id"];
                    var total_damage = response.data.result[i]["total_damage"];
                    data.push({
                        "Order No": purchase_order,
                        Product: product_name,
                        "Factory Order Number": manufacturing_order_no,
                        "Total Damage": total_damage,
                        "Date & Time": trans_date_time,
                        edit:
                            '<button class="btn btn-primary" onclick="edit(' +
                            dcr_id +
                            ')"><i class="fa fa-pencil-square-o" aria-hidden="true"></i></button>',
                        view:
                            '<button class="btn btn-success" onclick="view(' +
                            dcr_id +
                            ')"><i class="fa fa-eye" aria-hidden="true"></i></button>',
                        print:
                            '<button class="btn btn-instagram" onclick="print(' +
                            dcr_id +
                            ')"><i class="fa fa-print" aria-hidden="true"></i></button>',
                        delete:
                            '<button class="btn btn-danger" onclick="_delete(' +
                            dcr_id +
                            ')"><i class="fa fa-trash" aria-hidden="true"></i></button>',
                    });
                }

                var table = $("#myTable").DataTable();
                table.clear();
                table.rows.add(data).draw();
            }
        },

        error: function (error) {
            console.log(error);
        },
        complete: function () { },
    });
}

function edit(id) {
    location.href = "/qc/damageChecking?id=" + id + "&action=edit";
}

function view(id) {
    location.href = "/qc/damageChecking?id=" + id + "&action=view";
}

function _delete(id) {
    showAlert("Are You Sure?", id);
}

function showAlert(message, id) {
    swal({
        title: message,
        text: "Once deleted, you will not be able to recover this record!",
        icon: "warning",
        buttons: true,
        dangerMode: true,
    });

    $(".swal-button--confirm").on("click", function () {
        $.ajax({
            type: "DELETE",
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
            url: "/qc/DamageCheckingRecordsHeaderController/delete/" + id,
            success: function (response) {
                console.log(response);
                allDcRecords();
            },
            error: function (data) {
                console.log(data);
            },
        });
    });
}


function print(id) {

    $.ajax({
        type: "GET",
        url: "/qc/DamageCheckingRecordsHeaderController/damageCheckingReport/" + id,
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () {
        },
        success: function (response) {
            console.log(response);
            var result = response.data.result;
            console.log(result);
            damageCheckingPrint(result, 'PRINT');

        },
        error: function (error) {
            console.log(error);
            showErrorMessage();

        },
        complete: function () {
            //$('#btnPrint').text('Print');
            //$('.btn').prop("disabled", false);
        }

    });

}


function damageCheckingPrint(result, flag) {

    var headerFontSize = 8;
    var Title = [
        { text: '' }
    ];

    var header_data = result.header;


    var Header = [
        {
            content: [

                {
                    table: {
                        widths: ['*'],
                        headerRows: 1,
                        body: [
                            [{ text: Page.getReportName(), fontSize: 16, bold: true, alignment: 'center', border: [false, false, false, false] }],
                            [{
                                table: {
                                    widths: [150, '*', 150],
                                    headerRows: 1,
                                    body: [
                                        [{ text: '', fontSize: 9, bold: false, alignment: 'left', border: [false, false, false, false] }, { text: 'Damage Checking Records', fontSize: 14, bold: true, alignment: 'center', border: [false, false, false, false] }, { text: 'Document No : FO/PR/017', fontSize: 9, bold: false, alignment: 'right' }],
                                        [{ text: '', fontSize: 9, bold: false, alignment: 'left', border: [false, false, false, false] }, { text: '', fontSize: 9, bold: false, alignment: 'center', border: [false, false, false, false] }, { text: 'Issue Date : 2022/05/23', fontSize: 9, bold: false, alignment: 'right' }],
                                    ],

                                }, border: [false, false, false, false]
                            }],
                            [{
                                table: {
                                    widths: ['*', 150],
                                    headerRows: 1,
                                    body: [
                                        [{ text: '', fontSize: 9, bold: false, alignment: 'left', border: [false, false, false, false] }, { text: 'Product : ' + header_data.product, fontSize: 9, bold: false, alignment: 'right', border: [false, false, false, false] }],
                                        [{ text: '', fontSize: 9, bold: false, alignment: 'left', border: [false, false, false, false] }, { text: 'Factory Order Number : ' + header_data.factory_order_number, fontSize: 9, bold: false, alignment: 'right', border: [false, false, false, false] }],
                                        [{ text: '', fontSize: 9, bold: false, alignment: 'left', border: [false, false, false, false] }, { text: 'Date & Time : ' + header_data.trans_date_time, fontSize: 9, bold: false, alignment: 'right', border: [false, false, false, false] }],
                                    ],

                                }, border: [false, false, false, false]
                            }],
                        ],

                    },
                    margin: [0, 0],
                },

            ]
        }
    ];



    var footer_data = result.header;
    var Body = [
        {
            table: {
                widths: ['*', '*', '*', '*', '*', '*', '*', '*', '*', '*', '*', '*', '*', '*'],
                headerRows: 1,
                body: damageCheckingPrintBody(result.body),

            },

        },
        {
            table: {
                widths: ['*'],
                headerRows: 1,
                body: [
                    [{ text: 'SED - Seal Damage, BD - Block Damage, SLD - Slab Damage, PRD - Print Damage, PAD - Packing Damage, OD - Other Damage, SED - Seal Damage QC, BD - Block Damage QC, SLD - Slab Damage QC, PRD - Print Damage QC, PAD - Packing Damage QC, OD - Other Damage QC', fontSize: 7, margin: [0, 15, 0, 0], color: 'gray', bold: false, alignment: 'left', border: [false, false, false, false] }],
                ],


            }, border: [false, false, false, false]
        },
        {
            margin: [0, 10],
            table: {
                widths: ['*', '*', '*'],
                headerRows: 1,
                heights: 10,
                margin: [10, 10],
                body: [
                    [{ text: 'Checked By', fontSize: 8, alignment: 'left', bold: true, colSpan: 3 }, {}, {}],
                    [{ text: 'Signature', fontSize: 8, alignment: 'left', bold: true, }, { text: 'Name', fontSize: 8, alignment: 'left', bold: true, }, { text: 'Date', fontSize: 8, alignment: 'left', bold: true, }],
                    [{ text: '' }, { text: '' }, { text: '' }],
                ],

            }, border: [false, false, false, false]
        },

    ];




    var Footer = [
        {
            color: 'red',
            fontSize: 8,
            alignment: 'center',
            margin: [0, 0]
        }
    ];

    var page = new Page();
    page.setPageSize('A4');
    page.setPageOrientation('landscape');
    page.setPageMargin([10, 10, 10, 10]);
    page.setTitle(Title);
    page.setHeader(Header, Page.EVERY);
    page.setBody(Body);
    page.setFooter(Footer);
    if (flag == 'EXPORT') {
        page.export();
    } else if (flag == 'PRINT') {
        page.preview();
    }
}


function damageCheckingPrintBody(result) {
    var font_size = 8;
    var body = [];
    body.push([{ text: 'Shift', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'Hours', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'SED', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'BD', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'SLD', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'PRD', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'PAD', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'OD', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'QSED', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'QBD', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'QSLD', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'QPRD', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'QPAD', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'QOD', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    ]);

    var data = result.data;
    for (i = 0; i < data.length; i++) {
        body.push([
            { text: data[i].shift_name, fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].hour, fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].seal_damage, fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].block_damage, fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].slab_damage, fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].print_damage, fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].packing_damage, fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].other_damage, fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].qc_seal_damage, fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].qc_block_damage, fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].qc_slab_damage, fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].qc_print_damage, fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].qc_packing_damage, fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].qc_other_damage, fontSize: font_size, alignment: 'center', border: [true, true, true, true] },


        ]);
    }

    return body;
}



/**
* showSuccessMessage
* This function is used to show success message.
* @param message This is the paramter to require message content
*/
function showSuccessMessage(message) {
    toastr.success(message);
}


/**
* showWarningMessage
* This function is used to show warning message.
* @param message This is the paramter to require message content
*/
function showWarningMessage(message) {
    toastr.warning(message);
}



/**
* showErrorMessage
* This function is used to show error message.
* @param message This is the paramter to require message content
*/
function showErrorMessage() {
    toastr.error('Something went wrong');
}
