$(document).ready(function () {
    $("#myTable").DataTable({
        scrollX: true,
        order: [],
        columns: [
            { data: "Reference No" },
            { data: "Factory" },
            { data: "Supplier Name" },
            { data: "Inspection Date" },
            { data: "edit", className: "edit", orderable: false },
            { data: "view", className: "view", orderable: false },
            { data: "print", className: "print", orderable: false },
            { data: "delete", className: "delete", orderable: false },
        ],
        columnDefs: [
            { width: 30, targets: 4 },
            { width: 30, targets: 5 },
            { width: 30, targets: 6 },
            { width: 30, targets: 7 },
        ],
    });

    allPmRecords();
});

function allPmRecords() {
    $.ajax({
        type: "GET",
        url: "/qc/PackingMaterialChecklistHeaderController/records",
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () { },
        success: function (response) {
            console.log(response);
            if (response.data.success) {
                var data = [];

                for (i = 0; i < response.data.result.length; i++) {
                    var reference_no = response.data.result[i]["reference_no"];
                    var factory = response.data.result[i]["factory"];
                    var supplier_name = response.data.result[i]["supplier_name"];
                    var date = response.data.result[i]["date"];
                    var scl_id = response.data.result[i]["packing_material_id"];
                    data.push({
                        "Reference No": reference_no,
                        Factory: factory,
                        "Supplier Name": supplier_name,
                        "Inspection Date": date,
                        edit:
                            '<button class="btn btn-primary" onclick="edit(' +
                            scl_id +
                            ')"><i class="fa fa-pencil-square-o" aria-hidden="true"></i></button>',
                        view:
                            '<button class="btn btn-success" onclick="view(' +
                            scl_id +
                            ')"><i class="fa fa-eye" aria-hidden="true"></i></button>',
                        print:
                            '<button class="btn btn-instagram" onclick="print(' +
                            scl_id +
                            ')"><i class="fa fa-print" aria-hidden="true"></i></button>',
                        delete:
                            '<button class="btn btn-danger" onclick="_delete(' +
                            scl_id +
                            ')"><i class="fa fa-trash" aria-hidden="true"></i></button>',
                    });
                }

                var table = $("#myTable").DataTable();
                table.clear();
                table.rows.add(data).draw();
            }
        },

        error: function (error) {
            console.log(error);
        },
        complete: function () { },
    });
}

function edit(id) {
    location.href = "/qc/packingMaterial?id=" + id + "&action=edit";
}

function view(id) {
    location.href = "/qc/packingMaterial?id=" + id + "&action=view";
}

function _delete(id) {
    showAlert("Are You Sure?", id);
}

function showAlert(message, id) {
    swal({
        title: message,
        text: "Once deleted, you will not be able to recover this record!",
        icon: "warning",
        buttons: true,
        dangerMode: true,
    });

    $(".swal-button--confirm").on("click", function () {
        $.ajax({
            type: "DELETE",
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
            url: "/qc/PackingMaterialChecklistHeaderController/delete/" + id,
            success: function (response) {
                console.log(response);
                allPmRecords();
            },
            error: function (data) {
                console.log(data);
            },
        });
    });
}

function print(id) {
    $.ajax({
        type: "GET",
        url:
            "/qc/PackingMaterialChecklistHeaderController/packingMaterialCheckListReport/" +
            id,
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () { },
        success: function (response) {
            var result = response.data.result;
            console.log(result);
            supervisorCheckingPrint(result, 'PRINT');
        },
        error: function (error) {
            console.log(error);
            showErrorMessage();
        },
        complete: function () {

        },
    });
}

function supervisorCheckingPrint(result, flag) {

    console.log(result.body);


    var headerFontSize = 8;
    var Title = [{ text: "" }];

    var header_data = result.header;

    var Header = [
        {
            content: [
                {
                    table: {
                        widths: ["*"],
                        headerRows: 1,
                        body: [
                            [
                                {
                                    text: Page.getReportName(),
                                    fontSize: 16,
                                    bold: true,
                                    alignment: "center",
                                    border: [false, false, false, false],
                                },
                            ],
                            [
                                {
                                    text: "",
                                    fontSize: 14,
                                    bold: true,
                                    alignment: "center",
                                    border: [false, false, false, false],
                                },
                            ],
                            [{
                                table: {
                                    widths: [150, '*', 150],
                                    headerRows: 1,
                                    body: [
                                        [{ rowSpan: 2, text: '', fontSize: 9, bold: false, alignment: 'left', border: [false, false, false, false] }, { rowSpan: 2, text: 'Packing Material Check List', fontSize: 14, bold: true, alignment: 'center', border: [false, false, false, false] }, { text: 'Document No : FO/PR/011', fontSize: 9, bold: false, alignment: 'right' }],
                                        [{}, {}, { text: 'Issue Date : 2021/11/12', fontSize: 9, bold: false, alignment: 'right' }],
                                    ],

                                }, border: [false, false, false, false]
                            }],
                            [
                                {
                                    table: {
                                        widths: ["*", 150],
                                        headerRows: 1,
                                        body: [
                                            [
                                                {
                                                    text:
                                                        "Reference No : " +
                                                        header_data.reference_no,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "left",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                                {
                                                    text:
                                                        "Supplier Name : " +
                                                        header_data.supplier_name,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "right",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                            ],
                                            [
                                                {
                                                    text: "",
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "left",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                                {
                                                    text:
                                                        "Factory : " +
                                                        header_data.factory,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "right",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                            ],
                                            [
                                                {
                                                    text: "",
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "left",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                                {
                                                    text:
                                                        "Date : " +
                                                        header_data.date,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "right",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                            ],
                                        ],
                                    },
                                    border: [false, false, false, false],
                                },
                            ],
                        ],
                    },
                    margin: [0, 0],
                },
            ],
        },
    ];

    var footer_data = result.header;
    var Body = [
        { text: 'Packing Material Type - Strapping Rolls', style: 'subheader', fontSize: 9, },
        {

            table: {
                widths: [
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                ],
                headerRows: 1,
                heights: 4,
                body: getBodyData(result.body),
            }, margin: [0, 5],
        },
        { text: 'Packing Material Type -  Clips', style: 'subheader', fontSize: 9, },
        {
            table: {
                widths: [
                    "*",
                    "*",
                ],
                headerRows: 1,
                heights: 4,
                body: getBodyClipsData(result.body),
            }, margin: [0, 5],
        },
        { text: 'Packing Material Type - Stretch Film Rolls', style: 'subheader', fontSize: 9, },
        {
            table: {
                widths: [
                    "*",
                    "*",
                    "*",
                ],
                headerRows: 1,
                heights: 4,
                body: getBodyStretchFilmRollsData(result.body),
            }, margin: [0, 5],
        },
        { text: 'Packing Material Type - Carton Packings', style: 'subheader', fontSize: 9, },
        {
            table: {
                widths: [
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                ],
                headerRows: 1,
                heights: 4,
                body: getBodyCartonPackingsData(result.body),
            }, margin: [0, 5],
        },
        {
            margin: [0, 5],
            table: {
                widths: ['*', '*', '*'],
                headerRows: 1,
                heights: 5,
                margin: [10, 10],
                body: [
                    [{ text: 'Checked By', fontSize: 8, alignment: 'left', bold: true, colSpan: 3 }, {}, {}],
                    [{ text: 'Signature', fontSize: 8, alignment: 'left', bold: true, }, { text: 'Name', fontSize: 8, alignment: 'left', bold: true, }, { text: 'Date', fontSize: 8, alignment: 'left', bold: true, }],
                    [{ text: '' }, { text: '' }, { text: '' }],
                ],

            }, border: [false, false, false, false]
        },
    ];

    var Footer = [
        {
            color: "red",
            fontSize: 8,
            alignment: "center",
            margin: [0, 0],
        },
    ];

    var page = new Page();
    page.setPageSize("A4");
    page.setPageOrientation("landscape");
    page.setPageMargin([10, 10, 10, 10]);
    page.setTitle(Title);
    page.setHeader(Header, Page.EVERY);
    page.setBody(Body);
    page.setFooter(Footer);
    if (flag == "EXPORT") {
        page.export();
    } else if (flag == "PRINT") {
        page.preview();
    }
}

function getBodyData(result) {
    var font_size = 8;
    var body = [];
    body.push([{ text: 'Weight', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'Thickness', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'Appearance', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'Width', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'Remarks', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    ]);

    var data = result.data;
    for (i = 0; i < data.length; i++) {
        // 
        weight_strapping_rolls = data[i].weight_strapping_rolls;
        thickness_strapping_rolls = data[i].thickness_strapping_rolls;
        appearance_strapping_rolls = data[i].appearance_strapping_rolls;
        width_strapping_rolls = data[i].width_strapping_rolls;
        remarks_strapping_rolls = data[i].remarks_strapping_rolls;        

        body.push([
            { text: !weight_strapping_rolls ? "" : weight_strapping_rolls, fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].thickness_strapping_rolls ? thickness_strapping_rolls : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].appearance_strapping_rolls ? appearance_strapping_rolls : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].width_strapping_rolls ? width_strapping_rolls : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].remarks_strapping_rolls ? remarks_strapping_rolls : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
        ]);
    }

    return body;
}


function getBodyClipsData(result) {
    var font_size = 8;
    var body = [];
    body.push([{ text: 'Weight', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'Thickness', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    ]);

    var data = result.data;

    for (i = 0; i < data.length; i++) {
        hardness_clips = data[i].hardness_clips;
        remarks_clips = data[i].remarks_clips;

        body.push([
            { text: hardness_clips ? hardness_clips : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: remarks_clips ? remarks_clips : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
        ]);

    }

    return body;
}

function getBodyStretchFilmRollsData(result) {
    var font_size = 8;
    var body = [];
    body.push([{ text: '', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'Old', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'New', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    ]);

    var data = result.data;
    for (i = 0; i < data.length; i++) {
        old_weight_film_roll = data[i].old_weight_film_roll;
        new_weight_film_roll = data[i].new_weight_film_roll;
        old_appearance_film_roll = data[i].old_appearance_film_roll;
        new_appearance_film_roll = data[i].new_appearance_film_roll;
        old_is_sticky_film_roll = data[i].old_is_sticky_film_roll;
        new_is_sticky_film_roll = data[i].new_is_sticky_film_roll;
        remarks_film_roll = data[i].remarks_film_roll;

        body.push([
            { text: "Weight", fontSize: font_size, alignment: 'center' },
            { text: data[i].old_weight_film_roll ? old_weight_film_roll : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].new_weight_film_roll ? new_weight_film_roll : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
        ]);
        body.push([
            { text: "Appearance", fontSize: font_size, alignment: 'center' },
            { text: data[i].old_appearance_film_roll ? old_appearance_film_roll : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].new_appearance_film_roll ? new_appearance_film_roll : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
        ]);
        body.push([
            { text: "Sticky or Not", fontSize: font_size, alignment: 'center' },
            { text: data[i].old_is_sticky_film_roll ? old_is_sticky_film_roll : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].new_is_sticky_film_roll ? new_is_sticky_film_roll : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
        ]);
        body.push([
            { text: "Remarks", fontSize: font_size, alignment: 'center', },
            { text: data[i].remarks_film_roll ? remarks_film_roll : "", fontSize: font_size, alignment: 'center', colSpan: 2, border: [true, true, true, true] },
            {},
        ]);
    }

    return body;
}


function getBodyCartonPackingsData(result) {
    var font_size = 8;
    var body = [];
    body.push([{ text: '', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'New Length', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'New width', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'New Height', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'Old Length', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'Old width', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    { text: 'Old Height', fontSize: font_size, bold: true, alignment: 'center', border: [true, true, true, true] },
    ]);

    var data = result.data;
    for (i = 0; i < data.length; i++) {
        // 
        new_internal_length_carton_packings = data[i].new_internal_length_carton_packings
        new_internal_width_carton_packings = data[i].new_internal_width_carton_packings
        new_internal_height_carton_packings = data[i].new_internal_height_carton_packings
        old_internal_length_carton_packings = data[i].old_internal_length_carton_packings
        old_internal_width_carton_packings = data[i].old_internal_width_carton_packings
        old_internal_height_carton_packings = data[i].old_internal_height_carton_packings
        new_external_length_carton_packings = data[i].new_external_length_carton_packings
        new_external_width_carton_packings = data[i].new_external_width_carton_packings
        new_external_height_carton_packings = data[i].new_external_height_carton_packings
        old_external_length_carton_packings = data[i].old_external_length_carton_packings
        old_external_width_carton_packings = data[i].old_external_width_carton_packings
        old_external_height_carton_packings = data[i].old_external_height_carton_packings
        weight_carton_packings = data[i].weight_carton_packings
        appearance_carton_packings = data[i].appearance_carton_packings
        no_of_ply_carton_packings = data[i].no_of_ply_carton_packings
        color_carton_packings = data[i].color_carton_packings
        remarks_carton_packings = data[i].remarks_carton_packings


        body.push([
            { text: "Internal Size", fontSize: font_size, alignment: 'center' },
            { text: data[i].new_internal_length_carton_packings ? new_internal_length_carton_packings : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].new_internal_width_carton_packings ? new_internal_width_carton_packings : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].new_internal_height_carton_packings ? new_internal_height_carton_packings : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].old_internal_length_carton_packings ? old_internal_length_carton_packings : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].old_internal_width_carton_packings ? old_internal_width_carton_packings : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].old_internal_height_carton_packings ? old_internal_height_carton_packings : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
        ]);
        body.push([
            { text: "External Size", fontSize: font_size, alignment: 'center' },
            { text: data[i].new_external_length_carton_packings ? new_external_length_carton_packings : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].new_external_width_carton_packings ? new_external_width_carton_packings : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].new_external_height_carton_packings ? new_external_height_carton_packings : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].old_external_length_carton_packings ? old_external_length_carton_packings : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].old_external_width_carton_packings ? old_external_width_carton_packings : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
            { text: data[i].old_external_height_carton_packings ? old_external_height_carton_packings : "", fontSize: font_size, alignment: 'center', border: [true, true, true, true] },
        ]);
        body.push([
            { text: "Weight", fontSize: font_size, alignment: 'center' },
            { text: data[i].weight_carton_packings ? weight_carton_packings : "", fontSize: font_size, alignment: 'center', colSpan: 6, border: [true, true, true, true] },
            {},
            {},
            {},
            {},
            {},
        ]);
        body.push([
            { text: "Appearance", fontSize: font_size, alignment: 'center' },
            { text: data[i].appearance_carton_packings ? appearance_carton_packings : "", fontSize: font_size, alignment: 'center', colSpan: 6, border: [true, true, true, true] },
            {},
            {},
            {},
            {},
            {},
        ]);
        body.push([
            { text: "No of Ply", fontSize: font_size, alignment: 'center' },
            { text: data[i].no_of_ply_carton_packings ? no_of_ply_carton_packings : "", fontSize: font_size, alignment: 'center', colSpan: 6, border: [true, true, true, true] },
            {},
            {},
            {},
            {},
            {},
        ]);
        body.push([
            { text: "Color", fontSize: font_size, alignment: 'center' },
            { text: data[i].color_carton_packings ? color_carton_packings : "", fontSize: font_size, alignment: 'center', colSpan: 6, border: [true, true, true, true] },
            {},
            {},
            {},
            {},
            {},
        ]);
        body.push([
            { text: "Remarks", fontSize: font_size, alignment: 'center' },
            { text: data[i].remarks_carton_packings ? remarks_carton_packings : "", fontSize: font_size, alignment: 'center', colSpan: 6, border: [true, true, true, true] },
            {},
            {},
            {},
            {},
            {},
        ]);
    }

    return body;
}

/**
 * showSuccessMessage
 * This function is used to show success message.
 * @param message This is the paramter to require message content
 */
function showSuccessMessage(message) {
    toastr.success(message);
}

/**
 * showWarningMessage
 * This function is used to show warning message.
 * @param message This is the paramter to require message content
 */
function showWarningMessage(message) {
    toastr.warning(message);
}

/**
 * showErrorMessage
 * This function is used to show error message.
 * @param message This is the paramter to require message content
 */
function showErrorMessage() {
    toastr.error("Something went wrong");
}
